@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: SQLite setup/teardown for tests
 
-our $VERSION = '0.0208';
+our $VERSION = '0.0209';
 
 use Moo;
 use strictures 2;
@@ -121,7 +121,7 @@ Test::SQLite - SQLite setup/teardown for tests
 
 =head1 VERSION
 
-version 0.0208
+version 0.0209
 
 =head1 SYNOPSIS
 
@@ -129,15 +129,19 @@ version 0.0208
   use Test::SQLite;
 
   my $sqlite = Test::SQLite->new(database => '/some/where/production.db');
-
   my $dbh = $sqlite->dbh;
+  # Fiddle with the test database...
+  $dbh->disconnect;
 
   $sqlite = Test::SQLite->new(
     schema   => '/some/where/schema.sql',
     db_attrs => { RaiseError => 1, AutoCommit => 0 },
   );
-
+  # Explicitly use the dsn and db_attrs to connect:
   $dbh = DBI->connect($sqlite->dsn, '', '', $sqlite->db_attrs);
+  # Fiddle with the test database...
+  $dbh->commit;
+  $dbh->disconnect;
 
 =head1 DESCRIPTION
 
